@@ -40,7 +40,6 @@
 #include "color.h"
 #include "types.h"
 #include "utils.h"
-#include "../pixmaps/xconvers.xpm"
 
 /************************ DEFINES AND GLOBAL VARIABLES ***********************/
 
@@ -48,6 +47,7 @@
 #define PORTHISTORY     10
 
 extern GtkWidget *mainwindow;
+extern gchar *savedline;
 gchar *preferencesdir, *logfilename;
 gpointer cvhost, cvport;
 GdkFont *textfont;
@@ -58,6 +58,7 @@ gboolean connected = FALSE, locked = FALSE;
 GList *txhistory, *hostnamehistory, *porthistory;
 FILE *logfp;
 preferencestype preferences;
+gboolean coloryes;
 
 /**********************************MAIN WINDOW********************************/
 
@@ -78,13 +79,18 @@ void on_mainwindow_show(GtkWidget *widget, gpointer user_data)
 
   textfont = gdk_font_load(preferences.font->str);
   if (!preferences.menu) widget_visible("mainmenubar", 0);
-  if (!preferences.statusbar) widget_visible("mainstatusbar", 0);
+  if (!preferences.statusbar)
+  {
+    widget_visible("progressbar", 0);
+    widget_visible("mainstatusbar", 0);
+    widget_visible("statushbox", 0);
+  }
   if (!preferences.scrollbar)
   {
     mainscrolledwindow = lookup_widget(mainwindow, "mainscrolledwindow");
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(mainscrolledwindow), 
       GTK_POLICY_NEVER, GTK_POLICY_NEVER);
-  };
+  }
   g_string_sprintf(greeting, _("Welcome to %s"), PACKAGE);
   mainstatusbar = lookup_widget (mainwindow, "mainstatusbar");
   gtk_statusbar_push (GTK_STATUSBAR(mainstatusbar), 1, greeting->str);
@@ -168,9 +174,16 @@ gboolean on_mainwindow_delete_event(GtkWidget *widget, GdkEvent *event,
   gpointer user_data)
 {
   savehistory();
+
   if (txhistory) g_list_free(txhistory);
   if (hostnamehistory) g_list_free(hostnamehistory);
   if (porthistory) g_list_free(porthistory);
+  if (savedline) g_free(savedline);
+
+  gdk_window_get_size(mainwindow->window, &preferences.width, &preferences.height);
+  gdk_window_get_root_origin(mainwindow->window, &preferences.x, &preferences.y);
+
+  savepreferences(coloryes);
   gtk_exit(0);
   return FALSE;
 }
@@ -195,6 +208,8 @@ void on_open_activate(GtkMenuItem *menuitem, gpointer user_data)
   GtkWidget *opendialog;
 
   opendialog = create_opendialog();
+  set_title(opendialog, _("%s - open connection"));
+  set_icon(opendialog, _("open"));
   gtk_widget_show(opendialog);
 }
 
@@ -213,6 +228,8 @@ void on_close_activate(GtkMenuItem *menuitem, gpointer user_data)
   g_string_sprintf(labeltext, _("Close connection to %s ?"), (gchar *)cvhost);
   gtk_label_set_text(GTK_LABEL(closelabel), labeltext->str);
   g_string_free(labeltext, TRUE);
+  set_title(closedialog, _("%s - close connection"));
+  set_icon(closedialog, _("close"));
   gtk_widget_set_sensitive(mainwindow, 0);
   gtk_widget_show(closedialog);
 }
@@ -225,6 +242,8 @@ void on_close_activate(GtkMenuItem *menuitem, gpointer user_data)
 void on_preferences_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
   preferencesdialog = create_preferencesdialog();
+  set_title(preferencesdialog, _("%s - preferences"));
+  set_icon(preferencesdialog, _("preferences"));
   gtk_widget_show(preferencesdialog);
 }
 
@@ -235,16 +254,10 @@ void on_preferences_activate(GtkMenuItem *menuitem, gpointer user_data)
 void on_about_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
   GtkWidget *aboutdialog;
-  GtkStyle *aboutstyle;
-  GdkBitmap *bitmap;
-  GdkPixmap *icon;
 
   aboutdialog = create_aboutdialog();
-  gtk_widget_realize(aboutdialog);
-  aboutstyle = gtk_widget_get_style(aboutdialog);
-  icon = gdk_pixmap_create_from_xpm_d(aboutdialog->window, &bitmap, &aboutstyle->bg[GTK_STATE_NORMAL], xconvers_xpm);
-  gdk_window_set_icon(aboutdialog->window, NULL, icon, bitmap);
-  gdk_window_set_icon_name(aboutdialog->window, _("about"));
+  set_title(aboutdialog, _("%s - about"));
+  set_icon(aboutdialog, _("about"));
   gtk_widget_show(aboutdialog);
 }
 
@@ -281,7 +294,7 @@ void on_opendialog_show(GtkWidget *widget, gpointer user_data)
 void on_openOKbutton_clicked(GtkButton *button, gpointer user_data)
 {
   GtkWidget *opendialog, *hostnamecombo, *portcombo, *hostnamecomboentry,
-    *portcomboentry;
+    *portcomboentry, *menuclose, *menuopen;
   GList *node;
 
   opendialog = gtk_widget_get_toplevel(GTK_WIDGET(button));
@@ -293,6 +306,7 @@ void on_openOKbutton_clicked(GtkButton *button, gpointer user_data)
   strcpy(cvport, gtk_editable_get_chars(GTK_EDITABLE(portcomboentry), 0, -1));
   if (!strcmp(cvhost, "")) strcpy(cvhost, "localhost");
   if (!strcmp(cvport, "")) strcpy(cvport, "3600");
+
   node = g_list_find_custom(hostnamehistory, g_strdup(cvhost), (GCompareFunc)g_strncasecmp);
   if (!node) hostnamehistory = g_list_prepend(hostnamehistory, g_strdup(cvhost));
   else
@@ -303,8 +317,10 @@ void on_openOKbutton_clicked(GtkButton *button, gpointer user_data)
       hostnamehistory = g_list_prepend(hostnamehistory, g_strdup(cvhost));
     }
   }
+
   if (g_list_length(hostnamehistory) > HOSTNAMEHISTORY)
     hostnamehistory = g_list_remove(hostnamehistory, g_list_last(hostnamehistory)->data);
+
   node = g_list_find_custom(porthistory, g_strdup(cvport), (GCompareFunc)g_strncasecmp);
   if (!node) porthistory = g_list_prepend(porthistory, g_strdup(cvport));
   else
@@ -315,12 +331,20 @@ void on_openOKbutton_clicked(GtkButton *button, gpointer user_data)
       porthistory = g_list_prepend(porthistory, g_strdup(cvport));
     }
   }
+
   if (g_list_length(porthistory) > PORTHISTORY)
     porthistory = g_list_remove(porthistory, g_list_last(porthistory)->data);
+
   if (rxmonitor) gdk_input_remove(rxmonitor);
   if (connected) connected = FALSE;
+
+  menuclose = lookup_widget(mainwindow, "close");
+  menuopen = lookup_widget(mainwindow, "open");
+  gtk_widget_set_sensitive(menuopen, 0);
+  gtk_widget_set_sensitive(menuclose, 0);
+
   gtk_widget_destroy(gtk_widget_get_toplevel(GTK_WIDGET(button)));
-  cvconnect();
+  cvresolve();
 }
 
 /*
@@ -400,13 +424,17 @@ void on_preferencesdialog_show(GtkWidget *widget, gpointer user_data)
     *autologinchannelentry, *autologincommandsentry, *fontentry,
     *menucheckbutton, *statusbarcheckbutton, *scrollbarcheckbutton,
     *backgroundcolorbutton, *pixmapentry, *pixmapselectbutton,
-    *colorradiobutton, *pixmapradiobutton;
+    *colorradiobutton, *pixmapradiobutton, *poscheck, *sizecheck;
 
   /* set state of buttons */
   loggingcheckbutton = lookup_widget(widget, "loggingcheckbutton");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(loggingcheckbutton), preferences.logging);
   autologincheckbutton = lookup_widget(widget, "autologincheckbutton");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(autologincheckbutton), preferences.autologin);
+  sizecheck = lookup_widget(widget, "sizecheckbutton");
+  poscheck = lookup_widget(widget, "positioncheckbutton");
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(sizecheck), preferences.size);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(poscheck), preferences.origin);
 
   /* set autologin entries */
   autologinnameentry = lookup_widget(widget, "autologinnameentry");
@@ -578,6 +606,9 @@ on_colorbutton_pressed_event           (GtkWidget       *widget,
   rgb[1] = buttoncolor.green / 65535.0;
   rgb[2] = buttoncolor.blue / 65535.0;
   gtk_color_selection_set_color(GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(colorselectiondialog)->colorsel), rgb);
+
+  set_title(colorselectiondialog, _("%s - select color"));
+  set_icon(colorselectiondialog, _("color"));
   gtk_widget_set_sensitive(preferencesdialog, 0);
   gtk_widget_show(colorselectiondialog);
 
@@ -623,7 +654,7 @@ void on_radiobutton_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 void on_pixmapselectbutton_clicked (GtkButton *button, gpointer user_data)
 {
   GtkWidget *fileselectiondialog;
-  
+
   fileselectiondialog = create_fileselectiondialog();
   
   /* Don't need these buttons */
@@ -631,6 +662,8 @@ void on_pixmapselectbutton_clicked (GtkButton *button, gpointer user_data)
   gtk_widget_destroy(GTK_FILE_SELECTION(fileselectiondialog)->fileop_del_file);
   gtk_widget_destroy(GTK_FILE_SELECTION(fileselectiondialog)->fileop_ren_file);
 
+  set_title(fileselectiondialog, _("%s - select pixmap"));
+  set_icon(fileselectiondialog, _("pixmap"));
   gtk_widget_set_sensitive(preferencesdialog, 0);
   gtk_widget_show(fileselectiondialog);
 }
@@ -647,6 +680,8 @@ void on_fontbutton_clicked (GtkButton *button, gpointer user_data)
   fontselectiondialog = create_fontselectiondialog();
   gtk_font_selection_dialog_set_preview_text(GTK_FONT_SELECTION_DIALOG(fontselectiondialog), _("How about this font?"));
   gtk_font_selection_dialog_set_font_name(GTK_FONT_SELECTION_DIALOG(fontselectiondialog), preferences.font->str);
+  set_title(fontselectiondialog, _("%s - select font"));
+  set_icon(fontselectiondialog, _("font"));
   gtk_widget_set_sensitive(preferencesdialog, 0);
   gtk_widget_show(fontselectiondialog);
 }
@@ -663,17 +698,22 @@ void on_preferencesOKbutton_clicked(GtkButton *button, gpointer user_data)
   GtkWidget *loggingcheckbutton, *autologincheckbutton, *autologinnameentry,
     *autologinchannelentry, *autologincommandsentry, *maintext,
     *menucheckbutton, *statusbarcheckbutton, *scrollbarcheckbutton, 
-    *mainscrolledwindow, *colorradiobutton;
+    *mainscrolledwindow, *colorradiobutton, *sizecheck, *poscheck;
   GtkStyle *maintextstyle;
   GdkPixmap *pixmap = NULL;
   GdkBitmap *mask;
-  gboolean coloryes;
 
   /* Save state of logging */
   loggingcheckbutton = lookup_widget(preferencesdialog, "loggingcheckbutton");
   preferences.logging = gtk_toggle_button_get_active
     (GTK_TOGGLE_BUTTON(loggingcheckbutton));
 
+  /* save position and size */
+  sizecheck = lookup_widget(preferencesdialog, "sizecheckbutton");
+  poscheck = lookup_widget(preferencesdialog, "positioncheckbutton");
+  preferences.size = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sizecheck));
+  preferences.origin = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(poscheck));
+
   /* Save the entries for autologin */
   autologincheckbutton = lookup_widget(preferencesdialog, 
     "autologincheckbutton");
@@ -693,9 +733,12 @@ void on_preferencesOKbutton_clicked(GtkButton *button, gpointer user_data)
   menucheckbutton = lookup_widget(preferencesdialog, "menucheckbutton");
   preferences.menu = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(menucheckbutton));
   widget_visible("mainmenubar", preferences.menu);
+
   statusbarcheckbutton = lookup_widget(preferencesdialog, "statusbarcheckbutton");
   preferences.statusbar = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(statusbarcheckbutton));
+  widget_visible("progressbar", preferences.statusbar);
   widget_visible("mainstatusbar", preferences.statusbar);
+  widget_visible("statushbox", preferences.statusbar);
   scrollbarcheckbutton = lookup_widget(preferencesdialog, "scrollbarcheckbutton");
   preferences.scrollbar = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(scrollbarcheckbutton));
   mainscrolledwindow = lookup_widget(mainwindow, "mainscrolledwindow");
@@ -714,8 +757,6 @@ void on_preferencesOKbutton_clicked(GtkButton *button, gpointer user_data)
     if (!(pixmap)) coloryes = TRUE;
   }
 
-  savepreferences(coloryes);
-
   /* Turn logging on/off if it is set/unset and we are connected */
   if (preferences.logging && connected)
   {
@@ -786,14 +827,14 @@ void on_aboutdialog_show(GtkWidget *widget, gpointer user_data)
   abouthelptext = lookup_widget(widget, "abouthelptext");
   aboutlicenselabel = lookup_widget(widget, "aboutlicenselabel");
 
-  g_string_sprintf(info, _("\n%s version %s\nCopyright (C) 2000-2001 Joop Stakenborg\n\
-E-mail: <pa4tu@amsat.org>\nhttp://xconvers.sourceforge.net\n\n"), PACKAGE, VERSION);
+  g_string_sprintf(info, _("\n%s version %s\nCopyright (C) 2000-2002 Joop Stakenborg\n\
+E-mail: <pa4tu@amsat.org>\nhttp://people.debian.org/~pa3aba/xconvers.html\n\n"), PACKAGE, VERSION);
   gtk_label_set_text(GTK_LABEL(aboutcreditslabel), info->str);
 
   g_string_sprintf(info, _("PgUp: Scroll the receive window up.\nPgDn: Scroll the receive window down.\n\
 Up Arrow: Recall previously transmitted text.\nDn Arrow: Recall next transmitted text.\n\n\
-Alt+F: File menu (exit program).\nAlt+H: Host menu (open/close a connection).\n\
-Alt+S: Settings menu (preferences).\nAlt+P: Help menu (credits and help).\n"));
+Alt+P: Program menu (exit).\nAlt+H: Host menu (open/close a connection).\n\
+Alt+S: Settings menu (preferences).\nAlt+E: Help menu (credits and help).\n"));
   gtk_text_insert(GTK_TEXT(abouthelptext), NULL, NULL, NULL, info->str, -1);
 
   g_string_sprintf(info, _("Xconvers comes with ABSOLUTELY NO WARRANTY.\nThis is free software, and you are welcome to\n\
