@@ -23,6 +23,8 @@
  
 #include <gtk/gtk.h>
 #include <stdlib.h>
+#include <unistd.h>
+#include <strings.h>
 #include "support.h"
 #include "color.h"
 #include "net.h"
@@ -33,7 +35,7 @@ extern GdkFont *textfont;
 extern preferencestype preferences;
 extern gint buttonnumber, mousebutton;
 gchar *savedline;
-gint previousmessage = 0, usercolor = 0;
+gint previousmessage = 0, usercolor = 0, colorindex = 0;
 GHashTable *callsigns = NULL;
 
 /*
@@ -51,37 +53,53 @@ void maintext_add(gchar *msg, gint messagetype)
   GtkWidget *maintext;
   gchar **rxsplit = NULL, **linesplit = NULL;
   gchar *delimitedline = NULL, *insert = NULL, *callsign = NULL;
-  gchar *tmpstr = NULL;
-  gint i, colorindex = 0, lines = 0, crs = 0, numbytes = 0;
+  gint i, crs = 0, numbytes = 0;
   gint rxtype = DEFAULT_MESSAGE;
 
-  numbytes = strlen(msg);
   if (msg[0] == '\0') return;
+  numbytes = strlen(msg);
   maintext = lookup_widget(mainwindow, "maintext");
   switch (messagetype)
   {
     case MESSAGE_RX:
-      rxsplit = g_strsplit(msg, "\n", 0);
+      /* count carriage returns */
       for (i = 0; i < numbytes; i++) if (msg[i] == '\n') crs++;
-      for (lines = 0; lines <= crs + 1; lines++) if (!rxsplit[lines]) break;
-      if (lines > crs) tmpstr = g_strdup(rxsplit[lines - 1]); else tmpstr = NULL;
+
+      /* split up the incoming message into lines */
+      if (crs > 0) rxsplit = g_strsplit(msg, "\n", crs);
+
+      /* add a saved line which was incomplete in the previous message to the first line */
+      /* only attach to the first line if a carriage return was received */
       if (savedline)
       {
-        rxsplit[0] = g_strconcat(savedline, rxsplit[0], NULL);
-        savedline = NULL;
+        if (crs > 0)
+        { 
+          rxsplit[0] = g_strconcat(savedline, rxsplit[0], NULL);
+          savedline = g_strdup("");
+        }
+        else
+        {
+          savedline = g_strconcat(savedline, msg, NULL);
+        }
       }
+
+      /* now check for status, private and user messages in every line */
       for (i = 0; i < crs; i++)
       {
         insert = g_strdup_printf("%s\n", rxsplit[i]);
-        if (g_strncasecmp(insert, "*", 1) == 0)
-        {
+
+        if (insert[0] == '*'){
+          /* string received:'**' --> status message */
           if (insert[1] == '*') rxtype = STATUS_MESSAGE; else rxtype = DEFAULT_MESSAGE;
         }
-        if (g_strncasecmp(insert, "<", 1) == 0)
-        {
+        else if (insert[0] == '<') {
+          /* string received:'<*' --> private message */
           if (insert[1] == '*') rxtype = PRIVATE_MESSAGE; else rxtype = USER_MESSAGE;
         }
-        if (g_strncasecmp(insert, " ", 1) == 0) rxtype = previousmessage;
+        else if (insert[0] == ' ') rxtype = previousmessage;
+        /* character other than '<* ' on the first line */
+        else rxtype = DEFAULT_MESSAGE;
+
         switch (rxtype)
         {
           case STATUS_MESSAGE:
@@ -89,16 +107,27 @@ void maintext_add(gchar *msg, gint messagetype)
             previousmessage = STATUS_MESSAGE;
           break;
           case USER_MESSAGE:
-            if (g_strncasecmp(insert, " ", 1) != 0)
-            {
+            /* extract callsign from received string, call is in between '<' and '>' */
+            if (insert[0] == '<') {
               delimitedline = g_strdelimit(rxsplit[i], "<>", '#');
               linesplit = g_strsplit(delimitedline, "#", 3);
               callsign = g_strstrip(linesplit[1]);
-              colorindex = getcolor(callsign);
+              /* check if it really is a callsign */
+              if (strlen(callsign) > 2) { /* only check for now: callsign should be at least 3 letters */
+                colorindex = getcolor(callsign); /* get new or existing color for this callsign */
+                gtk_text_insert(GTK_TEXT(maintext), textfont, &preferences.userfgcolor[colorindex], NULL, insert, -1);
+                previousmessage = USER_MESSAGE;
+              } 
+              else {
+                gtk_text_insert(GTK_TEXT(maintext), textfont, &preferences.rxfgcolor, NULL, insert, -1);
+                previousmessage = DEFAULT_MESSAGE;
+              }
               g_strfreev(linesplit);
             }
-            gtk_text_insert(GTK_TEXT(maintext), textfont, &preferences.userfgcolor[colorindex], NULL, insert, -1);
-            previousmessage = USER_MESSAGE;
+            else {
+              gtk_text_insert(GTK_TEXT(maintext), textfont, &preferences.userfgcolor[colorindex], NULL, insert, -1);
+              previousmessage = USER_MESSAGE;
+            }
           break;
           case PRIVATE_MESSAGE:
             gtk_text_insert(GTK_TEXT(maintext), textfont, &preferences.privatefgcolor, &preferences.privatebgcolor, insert, -1);
@@ -115,8 +144,9 @@ void maintext_add(gchar *msg, gint messagetype)
         }
       }
       free(insert);
+      /* save incomplete line */
+      if (crs > 0 && rxsplit[crs]) savedline = g_strdup(rxsplit[crs]);
       g_strfreev(rxsplit);
-      if (tmpstr) savedline = g_strdup(tmpstr); else savedline = NULL;
     break;
     case MESSAGE_TX:
       gtk_text_insert(GTK_TEXT(maintext), textfont, &preferences.txfgcolor, NULL, msg, -1);
@@ -290,4 +320,4 @@ void updatepreview(GdkColor selectedcolor)
   gtk_text_insert(GTK_TEXT(colorstext), textfont, &preferences.userfgcolor[9], NULL, _("<user10>\n"), -1);
 
   gtk_text_thaw(GTK_TEXT(colorstext));
-}
\ No newline at end of file
+}
