@@ -31,4 +31,6 @@
 
 void maintext_add(gchar *msg, gint messagetype);
 gint getcolor(gchar *call);
-gchar *color_parse(gchar value[100]);
\ No newline at end of file
+gchar *color_parse(gchar value[100]);
+void setbuttoncolor(gchar *buttonname, GdkColor buttoncolor);
+void updatepreview(GdkColor selectedcolor);
