@@ -50,6 +50,7 @@ void loadhistory(void)
     histsplit = g_strsplit(history, ":", 2);
     if (!g_strcasecmp(histsplit[0], "tx"))
     {
+      g_strdelimit(histsplit[1], "_", ' ');
       txhistory = g_list_append(txhistory, g_string_new(histsplit[1]));
       txitem = g_list_length(txhistory);
     }
@@ -86,7 +87,10 @@ void savehistory(void)
       for(i=0; i<n; i++)
       {
         tx = g_list_nth_data(txhistory, i);
+        if (tx->len > 0) {
+        g_strdelimit(tx->str, " ", '_');
         fprintf(fp, "tx:%s\n", tx->str);
+        }
       }
     }
     if ((n = g_list_length(hostnamehistory)) > 0)
@@ -132,16 +136,15 @@ void tx_previous(void)
 {
   GtkWidget *mainentry;
   GList *node;
-  GString *tempstr;
+  gchar *tempstr;
 
   if (updown < txitem) updown++;
   if (txhistory)
   {
     node = g_list_nth_data(txhistory, txitem-updown);
-    tempstr = g_string_new(node->data);
+    tempstr = g_strdup(node->data);
     mainentry = lookup_widget (mainwindow, "mainentry");
-    gtk_entry_set_text(GTK_ENTRY(mainentry), tempstr->str);
-    g_string_free(tempstr, TRUE);
+    gtk_entry_set_text(GTK_ENTRY(mainentry), tempstr);
   }
 }
 
@@ -155,7 +158,7 @@ void tx_next(void)
 {
   GtkWidget *mainentry;
   GList *node;
-  GString *tempstr;
+  gchar *tempstr;
 
   mainentry = lookup_widget (mainwindow, "mainentry");
   if (updown > 0) updown--;
@@ -164,8 +167,7 @@ void tx_next(void)
     else
     {
       node = g_list_nth_data(txhistory, txitem-updown);
-      tempstr = g_string_new(node->data);
-      gtk_entry_set_text(GTK_ENTRY(mainentry), tempstr->str);
-      g_string_free(tempstr, TRUE);
+      tempstr = g_strdup(node->data);
+      gtk_entry_set_text(GTK_ENTRY(mainentry), tempstr);
     }
 }
\ No newline at end of file
