@@ -26,7 +26,9 @@
 #define MESSAGE_RX 1
 #define MESSAGE_TX 2
 
-void cvconnect(void);
+void cvresolve(void);
+gint resolvenonblock(void);
+void cvconnect(gchar *where);
 void cvdisconnect(void);
 void rx(gpointer data, gint source, GdkInputCondition condition);
 void tx(GString *message);
