@@ -26,6 +26,7 @@
 #endif
 #include <gtk/gtk.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <sys/stat.h>
 #include "support.h"
 #include "preferences.h"
@@ -73,40 +74,42 @@ void loadpreferences(void)
   preferences.menu = TRUE;
   preferences.statusbar = TRUE;
   preferences.scrollbar = TRUE;
+  preferences.origin = FALSE;
+  preferences.size = FALSE;
   preferences.font = g_string_new("fixed");
   colormap = gdk_colormap_get_system();
   gdk_color_parse("grey1", &preferences.backgroundcolor);
-  gdk_color_alloc(colormap, &preferences.backgroundcolor);
+  gdk_colormap_alloc_color(colormap, &preferences.backgroundcolor, FALSE, TRUE);
   gdk_color_parse("white", &preferences.txfgcolor);
-  gdk_color_alloc(colormap, &preferences.txfgcolor);
+  gdk_colormap_alloc_color(colormap, &preferences.txfgcolor, FALSE, TRUE);
   gdk_color_parse("light grey", &preferences.rxfgcolor);
-  gdk_color_alloc(colormap, &preferences.rxfgcolor);
+  gdk_colormap_alloc_color(colormap, &preferences.rxfgcolor, FALSE, TRUE);
   gdk_color_parse("red", &preferences.statusfgcolor);
-  gdk_color_alloc(colormap, &preferences.statusfgcolor);
+  gdk_colormap_alloc_color(colormap, &preferences.statusfgcolor, FALSE, TRUE);
   gdk_color_parse("pink", &preferences.privatefgcolor);
-  gdk_color_alloc(colormap, &preferences.privatefgcolor);
+  gdk_colormap_alloc_color(colormap, &preferences.privatefgcolor, FALSE, TRUE);
   gdk_color_parse("grey1", &preferences.privatebgcolor);
-  gdk_color_alloc(colormap, &preferences.privatebgcolor);
+  gdk_colormap_alloc_color(colormap, &preferences.privatebgcolor, FALSE, TRUE);
   gdk_color_parse("yellow", &preferences.userfgcolor[0]);
-  gdk_color_alloc(colormap, &preferences.userfgcolor[0]);
+  gdk_colormap_alloc_color(colormap, &preferences.userfgcolor[0], FALSE, TRUE);
   gdk_color_parse("green", &preferences.userfgcolor[1]);
-  gdk_color_alloc(colormap, &preferences.userfgcolor[1]);
+  gdk_colormap_alloc_color(colormap, &preferences.userfgcolor[1], FALSE, TRUE);
   gdk_color_parse("blue", &preferences.userfgcolor[2]);
-  gdk_color_alloc(colormap, &preferences.userfgcolor[2]);
+  gdk_colormap_alloc_color(colormap, &preferences.userfgcolor[2], FALSE, TRUE);
   gdk_color_parse("magenta", &preferences.userfgcolor[3]);
-  gdk_color_alloc(colormap, &preferences.userfgcolor[3]);
+  gdk_colormap_alloc_color(colormap, &preferences.userfgcolor[3], FALSE, TRUE);
   gdk_color_parse("orange", &preferences.userfgcolor[4]);
-  gdk_color_alloc(colormap, &preferences.userfgcolor[4]);
+  gdk_colormap_alloc_color(colormap, &preferences.userfgcolor[4], FALSE, TRUE);
   gdk_color_parse("cyan", &preferences.userfgcolor[5]);
-  gdk_color_alloc(colormap, &preferences.userfgcolor[5]);
+  gdk_colormap_alloc_color(colormap, &preferences.userfgcolor[5], FALSE, TRUE);
   gdk_color_parse("purple", &preferences.userfgcolor[6]);
-  gdk_color_alloc(colormap, &preferences.userfgcolor[6]);
+  gdk_colormap_alloc_color(colormap, &preferences.userfgcolor[6], FALSE, TRUE);
   gdk_color_parse("DarkKhaki", &preferences.userfgcolor[7]);
-  gdk_color_alloc(colormap, &preferences.userfgcolor[7]);
+  gdk_colormap_alloc_color(colormap, &preferences.userfgcolor[7], FALSE, TRUE);
   gdk_color_parse("DarkCyan", &preferences.userfgcolor[8]);
-  gdk_color_alloc(colormap, &preferences.userfgcolor[8]);
+  gdk_colormap_alloc_color(colormap, &preferences.userfgcolor[8], FALSE, TRUE);
   gdk_color_parse("DeepPink", &preferences.userfgcolor[9]);
-  gdk_color_alloc(colormap, &preferences.userfgcolor[9]);
+  gdk_colormap_alloc_color(colormap, &preferences.userfgcolor[9], FALSE, TRUE);
   preferences.commands = g_string_new("");
 
   /* open preferences file */
@@ -118,152 +121,87 @@ void loadpreferences(void)
   while(!feof(fp))
   {
     if (fscanf(fp, "%s %s", label, value) == EOF) break;
-    if (!g_strcasecmp(label, "logging"))
-    {
+    if (!g_strcasecmp(label, "logging")) {
       if (!g_strcasecmp(value,"on"))
         preferences.logging = TRUE;
     }
-    else
-    {
-      if (!g_strcasecmp(label, "autologin"))
-      {
-        if (!g_strcasecmp(value,"on"))
-          preferences.autologin = TRUE;
-      }
-      else
-      {
-        if (!g_strcasecmp(label, "name"))
-          preferences.name = g_string_new(value);
-        else
-        {
-          if (!g_strcasecmp(label, "menu"))
-          {
-            if (!g_strcasecmp(value,"off"))
-              preferences.menu = FALSE;
-          }
-          else
-          {
-            if (!g_strcasecmp(label, "statusbar"))
-            {
-              if (!g_strcasecmp(value,"off"))
-                preferences.statusbar = FALSE;
-            }
-            else
-            {
-              if (!g_strcasecmp(label, "scrollbar"))
-              {
-                if (!g_strcasecmp(value,"off"))
-                  preferences.scrollbar = FALSE;
-              }
-              else
-              {
-                if (!g_strcasecmp(label, "channel"))
-                  preferences.channel = g_string_new(value);
-                else
-                {
-                  if (!g_strcasecmp(label, "font"))
-                    preferences.font = g_string_new(value);
-                  else 
-                  {
-                    if (!g_strcasecmp(label, "backgroundpixmap"))
-                      preferences.backgroundpixmap = g_string_new(value);
-                    else
-                    {
-                      if (!g_strcasecmp(label, "commands"))
-                        {
-                        g_strdelimit(value, "-", ' ');
-                        g_strchug(g_strchomp(value));
-                        preferences.commands = g_string_new(value);
-                        }
-                      else 
-                      {
-                        if (!g_strcasecmp(label, "backgroundcolor"))
-                          gdk_color_parse(color_parse(value), &preferences.backgroundcolor);
-                        else 
-                        {
-                          if (!g_strcasecmp(label, "txfgcolor"))
-                            gdk_color_parse(color_parse(value), &preferences.txfgcolor);
-                          else
-                          {
-                            if (!g_strcasecmp(label, "rxfgcolor"))
-                              gdk_color_parse(color_parse(value), &preferences.rxfgcolor);
-                            else
-                            {
-                              if (!g_strcasecmp(label, "statusfgcolor"))
-                                gdk_color_parse(color_parse(value), &preferences.statusfgcolor);
-                              else
-                              {
-                                if (!g_strcasecmp(label, "privatefgcolor"))
-                                  gdk_color_parse(color_parse(value), &preferences.privatefgcolor);
-                                else
-                                {
-                                  if (!g_strcasecmp(label, "privatebgcolor"))
-                                  gdk_color_parse(color_parse(value), &preferences.privatebgcolor);
-                                  else
-                                  {
-                                    if (!g_strcasecmp(label, "user1fgcolor"))
-                                     gdk_color_parse(color_parse(value), &preferences.userfgcolor[0]);
-                                    else
-                                    {
-                                      if (!g_strcasecmp(label, "user2fgcolor"))
-                                        gdk_color_parse(color_parse(value), &preferences.userfgcolor[1]);
-                                      else
-                                      {
-                                        if (!g_strcasecmp(label, "user3fgcolor"))
-                                          gdk_color_parse(color_parse(value), &preferences.userfgcolor[2]);
-                                        else
-                                        {
-                                          if (!g_strcasecmp(label, "user4fgcolor"))
-                                            gdk_color_parse(color_parse(value), &preferences.userfgcolor[3]);
-                                          else
-                                          {
-                                            if (!g_strcasecmp(label, "user5fgcolor"))
-                                              gdk_color_parse(color_parse(value), &preferences.userfgcolor[4]);
-                                            else
-                                            {
-                                              if (!g_strcasecmp(label, "user6fgcolor"))
-                                                gdk_color_parse(color_parse(value), &preferences.userfgcolor[5]);
-                                              else
-                                              {
-                                                if (!g_strcasecmp(label, "user7fgcolor"))
-                                                  gdk_color_parse(color_parse(value), &preferences.userfgcolor[6]);
-                                                else
-                                                {
-                                                  if (!g_strcasecmp(label, "user8fgcolor"))
-                                                    gdk_color_parse(color_parse(value), &preferences.userfgcolor[7]);
-                                                  else
-                                                  {
-                                                    if (!g_strcasecmp(label, "user9fgcolor"))
-                                                      gdk_color_parse(color_parse(value), &preferences.userfgcolor[8]);
-                                                    else
-                                                    {
-                                                      if (!g_strcasecmp(label, "user10fgcolor"))
-                                                        gdk_color_parse(color_parse(value), &preferences.userfgcolor[9]);
-                                                    }
-                                                  }
-                                                }
-                                              }
-                                            }
-                                          }
-                                        }
-                                      }
-                                    }
-                                  }
-                                }
-                              }
-                            }
-                          }
-                        }
-                      }
-                    }
-                  }
-                }
-              }
-            }
-          }
-        }
-      }
+    else if (!g_strcasecmp(label, "autologin")) {
+      if (!g_strcasecmp(value,"on"))
+        preferences.autologin = TRUE;
     }
+    else if (!g_strcasecmp(label, "name"))
+      preferences.name = g_string_new(value);
+    else if (!g_strcasecmp(label, "menu")) {
+      if (!g_strcasecmp(value,"off"))
+        preferences.menu = FALSE;
+    }
+    else if (!g_strcasecmp(label, "statusbar")) {
+      if (!g_strcasecmp(value,"off"))
+        preferences.statusbar = FALSE;
+    }
+    else if (!g_strcasecmp(label, "scrollbar")) {
+      if (!g_strcasecmp(value,"off"))
+        preferences.scrollbar = FALSE;
+    }
+    else if (!g_strcasecmp(label, "channel"))
+      preferences.channel = g_string_new(value);
+    else if (!g_strcasecmp(label, "font"))
+      preferences.font = g_string_new(value);
+    else if (!g_strcasecmp(label, "backgroundpixmap"))
+      preferences.backgroundpixmap = g_string_new(value);
+    else if (!g_strcasecmp(label, "commands")) {
+      g_strdelimit(value, "-", ' ');
+      g_strchug(g_strchomp(value));
+      preferences.commands = g_string_new(value);
+    }
+    else if (!g_strcasecmp(label, "backgroundcolor"))
+      gdk_color_parse(color_parse(value), &preferences.backgroundcolor);
+    else if (!g_strcasecmp(label, "txfgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.txfgcolor);
+    else if (!g_strcasecmp(label, "rxfgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.rxfgcolor);
+    else if (!g_strcasecmp(label, "statusfgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.statusfgcolor);
+    else if (!g_strcasecmp(label, "privatefgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.privatefgcolor);
+    else if (!g_strcasecmp(label, "privatebgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.privatebgcolor);
+    else if (!g_strcasecmp(label, "user1fgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.userfgcolor[0]);
+    else if (!g_strcasecmp(label, "user2fgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.userfgcolor[1]);
+    else if (!g_strcasecmp(label, "user3fgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.userfgcolor[2]);
+    else if (!g_strcasecmp(label, "user4fgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.userfgcolor[3]);
+    else if (!g_strcasecmp(label, "user5fgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.userfgcolor[4]);
+    else if (!g_strcasecmp(label, "user6fgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.userfgcolor[5]);
+    else if (!g_strcasecmp(label, "user7fgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.userfgcolor[6]);
+    else if (!g_strcasecmp(label, "user8fgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.userfgcolor[7]);
+    else if (!g_strcasecmp(label, "user9fgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.userfgcolor[8]);
+    else if (!g_strcasecmp(label, "user10fgcolor"))
+      gdk_color_parse(color_parse(value), &preferences.userfgcolor[9]);
+    else if (!g_strcasecmp(label, "size")) {
+      if (!g_strcasecmp(value, "on")) 
+        preferences.size = TRUE;
+    }
+    else if (!g_strcasecmp(label, "origin")) {
+      if (!g_strcasecmp(value, "on"))
+        preferences.origin = TRUE; 
+    }
+    else if (!g_strcasecmp(label, "x"))
+      preferences.x = atoi(value);
+    else if (!g_strcasecmp(label, "y"))
+      preferences.y = atoi(value);
+    else if (!g_strcasecmp(label, "width"))
+      preferences.width = atoi(value);
+    else if (!g_strcasecmp(label, "height"))
+      preferences.height = atoi(value);
   }
   fclose(fp);
 }
@@ -275,7 +213,7 @@ void loadpreferences(void)
  
 void savepreferences(gboolean coloryes)
 {
-  gchar *preferencesfile, *commandstring;
+  gchar *preferencesfile, *commandstring, *x, *y, *width, *height;
   FILE *fp;
 
   /* open preferences file */
@@ -284,7 +222,7 @@ void savepreferences(gboolean coloryes)
   if (fp == NULL) return;
 
   /* warning and version */
-  fprintf(fp, "# settings file for xconvers, do not edit\n");
+  fprintf(fp, "# settings file for %s, do not edit\n", PACKAGE);
   fprintf(fp, "version %s\n", VERSION);
 
   /* settings */
@@ -331,5 +269,17 @@ void savepreferences(gboolean coloryes)
   fprintf(fp, "user8fgcolor %04X,%04X,%04X\n", preferences.userfgcolor[7].red, preferences.userfgcolor[7].green, preferences.userfgcolor[7].blue);
   fprintf(fp, "user9fgcolor %04X,%04X,%04X\n", preferences.userfgcolor[8].red, preferences.userfgcolor[8].green, preferences.userfgcolor[8].blue);
   fprintf(fp, "user10fgcolor %04X,%04X,%04X\n", preferences.userfgcolor[9].red, preferences.userfgcolor[9].green, preferences.userfgcolor[9].blue);
+
+  if (preferences.origin) fprintf(fp, "origin on\n");
+  if (preferences.size) fprintf(fp, "size on\n");
+  x = g_strdup_printf("%d", preferences.x);
+  fprintf(fp, "x %s\n", x);
+  y = g_strdup_printf("%d", preferences.y);
+  fprintf(fp, "y %s\n", y);
+  width = g_strdup_printf("%d", preferences.width);
+  fprintf(fp, "width %s\n", width);
+  height = g_strdup_printf("%d", preferences.height);
+  fprintf(fp, "height %s\n", height);
+
   fclose(fp);
 }
