@@ -23,5 +23,4 @@
 
 void dircheck(void);
 void loadpreferences(void);
-void savepreferences(void);
-void widget_visible(gchar *name, gboolean state);
\ No newline at end of file
+void savepreferences(gboolean coloryes);
\ No newline at end of file
