@@ -40,4 +40,10 @@ typedef struct
   GdkColor privatefgcolor;
   GdkColor privatebgcolor;
   GdkColor userfgcolor[10];
+  gboolean origin;
+  gboolean size;
+  gint x;
+  gint y;
+  gint width;
+  gint height;
 } preferencestype;
\ No newline at end of file
