@@ -23,3 +23,6 @@
 
 void widget_visible(gchar *name, gboolean state);
 gboolean remove_calls(gchar *key, gpointer value, gpointer user_data);
+void set_icon(GtkWidget *dialog, gchar *name);
+void set_title(GtkWidget *dialog, gchar *format);
+void updatestatusbar(GString *statusmessage);
\ No newline at end of file
